Class: EspnPub::Entities::Base
- Inherits:
-
Object
- Object
- EspnPub::Entities::Base
- Defined in:
- lib/espn_pub/entities/base.rb
Overview
Base entity that holds a shared ESPN API client.
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Returns the value of attribute client.
Instance Method Summary collapse
-
#initialize ⇒ void
constructor
Initialize the base entity and create the shared client.
Constructor Details
#initialize ⇒ void
Initialize the base entity and create the shared client.
12 13 14 |
# File 'lib/espn_pub/entities/base.rb', line 12 def initialize @client = init_client end |
Instance Attribute Details
#client ⇒ Object (readonly)
Returns the value of attribute client.
7 8 9 |
# File 'lib/espn_pub/entities/base.rb', line 7 def client @client end |